@@ -392,6 +392,23 @@ struct CHALLENGER_DatabasePlugin
                       char **client_redirect_uri);
 
 
+  /**
+   * Return address known for a particular nonce.
+   *
+   * @param cls
+   * @param nonce unique nonce to use to identify the validation
+   * @param[out] address set to client-provided address, can be set to NULL!
+   * @return transaction status:
+   *   #GNUNET_DB_STATUS_SUCCESS_ONE_RESULT if the nonce was found
+   *   #GNUNET_DB_STATUS_SUCCESS_NO_RESULTS if we do not know the nonce
+   *   #GNUNET_DB_STATUS_HARD_ERROR on failure
+   */
+  enum GNUNET_DB_QueryStatus
+    (*address_get)(void *cls,
+                   const struct CHALLENGER_ValidationNonceP *nonce,
+                   json_t **address);
+
+
   /**
    * Return validation details including PKCE parameters. Used by `/solve`, `/auth`, and
    * `/info` endpoints to authorize and return validated user address to the client.
